@@ -40,7 +40,7 @@ import msgparsing
 from diff import seddiff
 
 
-VERSION = '1.34'
+VERSION = '1.35'
 
 
 class IrcDisconnectError(Exception): ...
@@ -108,8 +108,8 @@ class ClientSettings(NamedTuple):
         elif not self.downloads_directory.is_dir():
             return f'{self.downloads_directory} is not a directory'
 
-        if not os.access(self.downloads_directory, os.W_OK | os.R_OK | os.X_OK):
-            return 'Insufficient permissions on downloads directory'
+        if self.formatted_max_lines and not os.access(self.downloads_directory, os.W_OK | os.R_OK | os.X_OK):
+            return f'Insufficient permissions on downloads directory: {self.downloads_directory}'
 
         return None
 
@@ -1029,7 +1029,7 @@ def main() -> None:
                                 help='Set a suffix for the syslog identifier')
     parser.add_argument('--ignored-channels', type=str, action='store', dest='ignored_channels', default='',
                                 help='Comma separated list of channels to not join when autojoin is enabled')
-    parser.add_argument('--downloads-directory', type=str, action='store', dest='downloads_directory', default='/tmp',
+    parser.add_argument('--downloads-directory', type=str, action='store', dest='downloads_directory', default='.',
                                 help='Where to create files for automatic downloads')
     parser.add_argument('--formatted-max-lines', type=int, action='store', dest='formatted_max_lines', default=0,
                                 help='Maximum amount of lines in a formatted text to send to the client rather than store in a file.\n'
@@ -1055,7 +1055,7 @@ def main() -> None:
 
     # Exit if their chosden ip isn't local. User can override with -o if they so dare
     if not ip.startswith('127') and not overridelocalip:
-        exit('supplied ip isn\'t local\nlocalslackirc has no encryption or ' \
+        abort('supplied ip isn\'t local\nlocalslackirc has no encryption or ' \
                 'authentication, it\'s recommended to only allow local connections\n' \
                 'you can override this with -o')
 
@@ -1083,7 +1083,7 @@ def main() -> None:
     try:
         formatted_max_lines = int(environ.get('FORMATTED_MAX_LINES', args.formatted_max_lines))
     except:
-        exit('FORMATTED_MAX_LINES is not a valid int')
+        abort('FORMATTED_MAX_LINES is not a valid int')
 
     yellers_str = environ.get('SILENCED_YELLERS', args.silenced_yellers)
     if yellers_str:
@@ -1100,9 +1100,9 @@ def main() -> None:
             with open(args.tokenfile) as f:
                 token = f.readline().strip()
         except IsADirectoryError:
-            exit(f'Not a file {args.tokenfile}')
+            abort(f'Not a file {args.tokenfile}')
         except (FileNotFoundError, PermissionError):
-            exit(f'Unable to open the token file {args.tokenfile}')
+            abort(f'Unable to open the token file {args.tokenfile}')
 
     if 'COOKIE' in environ:
         cookie: str | None = environ['COOKIE']
@@ -1114,12 +1114,12 @@ def main() -> None:
             else:
                 cookie = None
         except (FileNotFoundError, PermissionError):
-            exit(f'Unable to open the cookie file {args.cookiefile}')
+            abort(f'Unable to open the cookie file {args.cookiefile}')
         except IsADirectoryError:
-            exit(f'Not a file {args.cookiefile}')
+            abort(f'Not a file {args.cookiefile}')
 
     if token.startswith('xoxc-') and not cookie:
-        exit('The cookie is needed for this kind of slack token')
+        abort('The cookie is needed for this kind of slack token')
 
     provider = Provider.SLACK
 
@@ -1130,13 +1130,13 @@ def main() -> None:
         if status_file is not None:
             if status_file.exists():
                 if not os.access(status_file, os.O_RDWR):
-                    exit('Status file needs to have read write permissions')
+                    abort('Status file needs to have read write permissions')
                 previous_status = status_file.read_bytes()
             else:
                 try:
                     status_file.write_bytes(b'')
                 except Exception as e:
-                    exit(f'Failure when creating the status file {e}')
+                    abort(f'Failure when creating the status file {e}')
 
         clientsettings = ClientSettings(
             nouserlist=nouserlist,
@@ -1150,7 +1150,7 @@ def main() -> None:
         )
         verify = clientsettings.verify()
         if verify is not None:
-            exit(verify)
+            abort(verify)
 
         serversocket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
         serversocket.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
