@@ -17,7 +17,8 @@
 # author Salvo "LtWorf" Tomaselli <tiposchi@tiscali.it>
 
 from os import isatty
-from syslog import LOG_INFO, LOG_DEBUG, syslog
+import sys
+from syslog import LOG_INFO, LOG_DEBUG, syslog, LOG_ERR
 from syslog import openlog as _openlog
 
 __all__ = [
@@ -25,6 +26,8 @@ __all__ = [
     'openlog',
     'set_debug',
     'debug',
+    'error',
+    'abort',
 ]
 
 
@@ -44,15 +47,19 @@ def openlog(suffix: str) -> None:
     _openlog(f'localslackirc{suffix}')
 
 
-def log(*args) -> None:
+def log(*args, log_level=LOG_INFO) -> None:
     """
     Logs to stdout or to syslog depending on if
     running with a terminal attached.
     """
     if tty:
-        print(*args)
+        if log_level in {LOG_DEBUG, LOG_INFO}:
+            f = sys.stdout
+        else:
+            f = sys.stderr
+        print(*args,file=f)
         return
-    syslog(LOG_INFO, ' '.join(str(i) for i in args))
+    syslog(log_level, ' '.join(str(i) for i in args))
 
 
 def set_debug(state: str|bool) -> None:
@@ -61,8 +68,11 @@ def set_debug(state: str|bool) -> None:
 
 
 def debug(*args) -> None:
-    if not debug_enabled:
-        return
-    if tty:
-        print(*args)
-    syslog(LOG_DEBUG, ' '.join(str(i) for i in args))
+    log(*args, log_level=LOG_DEBUG)
+
+def error(*args) -> None:
+    log(*args, log_level=LOG_ERR)
+
+def abort(*args) -> None:
+    log(*args, log_level=LOG_ERR)
+    sys.exit(1)
