@@ -1,5 +1,5 @@
 # localslackirc
-# Copyright (C) 2018-2024 Salvo "LtWorf" Tomaselli
+# Copyright (C) 2018-2025 Salvo "LtWorf" Tomaselli
 #
 # localslackirc is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@ import datetime
 from dataclasses import dataclass, field
 import json
 from time import time
-from typing import Literal, Optional, Any, NamedTuple, Sequence, Type, TypeVar
+from typing import Literal, Any, NamedTuple, Sequence, Type, TypeVar
 
 from typedload import dataloader
 
@@ -69,14 +69,21 @@ class Response(NamedTuple):
     """
     ok: bool
     headers: dict[str, str]
-    ts: Optional[float] = None
-    error: Optional[str] = None
+    ts: float | None = None
+    error: str | None = None
 
 
 @dataclass
 class DeletedFile:
     file_access: Literal['file_not_found']
 
+@dataclass
+class Presence:
+    presence: Literal["active", "away"]
+
+    def away(self) -> bool:
+        return self.presence == "away"
+
 @dataclass
 class File:
     file_access: Literal['visible']
@@ -84,9 +91,9 @@ class File:
     url_private: str
     size: int
     user: str
-    name: Optional[str] = None
-    title: Optional[str] = None
-    mimetype: Optional[str] = None
+    name: str | None = None
+    title: str | None = None
+    mimetype: str | None = None
 
 @dataclass
 class TabutuFile:
@@ -137,7 +144,7 @@ class Channel:
     # Last updated?
     updated: int = 0
 
-    latest: Optional[LatestMessage] = None
+    latest: LatestMessage | None = None
 
     @property
     def name(self):
@@ -162,7 +169,7 @@ class Message:
     user: str  # The user id
     text: str
     ts: float
-    thread_ts: Optional[str] = None
+    thread_ts: str | None = None
     files: list[File] = field(default_factory=list)
 
 
@@ -170,7 +177,7 @@ class NoChanMessage(NamedTuple):
     user: str
     text: str
     ts: float
-    thread_ts: Optional[str] = None
+    thread_ts: str | None = None
 
 
 class ActionMessage(Message):
@@ -211,7 +218,7 @@ class MessageDelete:
     files: list[File] = field(default_factory=list)
 
     @property
-    def thread_ts(self) -> Optional[str]:
+    def thread_ts(self) -> str | None:
         return self.previous_message.thread_ts
 
     @property
@@ -231,7 +238,7 @@ class UserTyping(NamedTuple):
 
 class Profile(NamedTuple):
     real_name: str = 'noname'
-    email: Optional[str] = None
+    email: str | None = None
     status_text: str = ''
     is_restricted: bool = False
     is_ultra_restricted: bool = False
@@ -244,9 +251,9 @@ class MessageBot:
     _text: str = field(metadata={'name': 'text'})
     username: str
     channel: str
-    bot_id: Optional[str] = None
+    bot_id: str | None = None
     attachments: list[dict[str, Any]] = field(default_factory=list)
-    thread_ts: Optional[str] = None
+    thread_ts: str | None = None
     files: list[File] = field(default_factory=list)
 
     @property
@@ -307,11 +314,11 @@ class HistoryBotMessage:
     type: Literal['message']
     subtype: Literal['bot_message']
     text: str
-    bot_id: Optional[str]
+    bot_id: str | None
     username: str = 'bot'
     ts: float = 0
     files: list[File | DeletedFile | TabutuFile] = field(default_factory=list)
-    thread_ts: Optional[str] = None
+    thread_ts: str | None = None
     attachments: list[dict[str, Any]] = field(default_factory=list)
 
 
@@ -322,7 +329,7 @@ class HistoryMessage:
     text: str
     ts: float
     files: list[File | DeletedFile | TabutuFile] = field(default_factory=list)
-    thread_ts: Optional[str] = None
+    thread_ts: str | None = None
 
 
 class NextCursor(NamedTuple):
@@ -333,12 +340,12 @@ class History(NamedTuple):
     ok: Literal[True]
     messages: list[HistoryMessage|HistoryBotMessage]
     has_more: bool
-    response_metadata: Optional[NextCursor] = None
+    response_metadata: NextCursor | None = None
 
 
 class Conversations(NamedTuple):
     channels: list[Channel]
-    response_metadata: Optional[NextCursor] = None
+    response_metadata: NextCursor | None = None
 
 
 SlackEvent = (
@@ -388,7 +395,7 @@ class SlackStatus:
 
 
 class Slack:
-    def __init__(self, token: str, cookie: Optional[str], previous_status: Optional[bytes]) -> None:
+    def __init__(self, token: str, cookie: str | None, previous_status: bytes | None) -> None:
         """
         A slack client object.
 
@@ -404,11 +411,11 @@ class Slack:
         self._channelscache: list[Channel] = []
         self._joinedchannelscache: list[Channel] = []
         self._get_members_cache: dict[str, set[str]] = {}
-        self._get_members_cache_cursor: dict[str, Optional[str]] = {}
+        self._get_members_cache_cursor: dict[str, str | None] = {}
         self._internalevents: list[SlackEvent] = []
         self._sent_by_self: set[float] = set()
         self._wsblock: int = 0 # Semaphore to block the socket and avoid events being received before their API call ended.
-        self.login_info: Optional[LoginInfo] = None
+        self.login_info: LoginInfo | None = None
         self.loader = dataloader.Loader()
 
         if previous_status is None:
@@ -429,7 +436,7 @@ class Slack:
         log('Login in slack')
         self.login_info = await self.client.login(15)
 
-    async def get_history(self, channel: Channel|IM|str, ts: str, cursor: Optional[NextCursor]=None, limit: int=1000, inclusive: bool=False) -> History:
+    async def get_history(self, channel: Channel|IM|str, ts: str, cursor: NextCursor | None=None, limit: int=1000, inclusive: bool=False) -> History:
         p = await self.client.api_call(
             'conversations.history',
             channel=channel if isinstance(channel, str) else channel.id,
@@ -596,7 +603,7 @@ class Slack:
         if not response.ok:
             raise ResponseException(response.error)
 
-    async def add_annoy(self, username, expiration: float) -> None:
+    async def add_annoy(self, username: str, expiration: float) -> None:
         user_id = (await self.get_user_by_name(username)).id
         self._status.annoy[user_id] = expiration
 
@@ -660,7 +667,7 @@ class Slack:
             if i.random_reaction():
                 try:
                     await self.add_reaction(msg, i.reaction)
-                except:
+                except Exception:
                     # Remove reactions that fail
                     rlist.remove(i)
                     return
@@ -677,6 +684,13 @@ class Slack:
         if not response.ok:
             raise ResponseException(response.error)
 
+    async def isAway(self, user: User) -> bool:
+        r = await self.client.api_call('users.getPresence', user=user.id)
+        response = self.tload(r, Response)
+        if not response.ok:
+            raise ResponseException(response.error)
+        return self.tload(r, Presence).away()
+
     async def join(self, channel: Channel) -> None:
         r = await self.client.api_call('conversations.join', channel=channel.id)
         response = self.tload(r, Response)
@@ -850,7 +864,7 @@ class Slack:
             thread_ts=thread_ts,
         )
 
-    async def get_im(self, im_id: str) -> Optional[IM]:
+    async def get_im(self, im_id: str) -> IM | None:
         if not im_id.startswith('D'):
             return None
         for uid, imid in self._imcache.items():
@@ -914,7 +928,7 @@ class Slack:
         else:
             raise KeyError(response)
 
-    async def send_file(self, channel_id: str, filename: str, content: bytes, thread_ts: Optional[str]) -> None:
+    async def send_file(self, channel_id: str, filename: str, content: bytes, thread_ts: str | None) -> None:
         """
         Send a file to a channel or group or whatever.
 
@@ -950,7 +964,7 @@ class Slack:
         thread_ts = channel.thread_ts if isinstance(channel, MessageThread) else None
         return await self._send_message(channel.id, msg, action, thread_ts, re_send_to_irc)
 
-    async def _send_message(self, channel_id: str, msg: str, action: bool, thread_ts: Optional[str], re_send_to_irc: bool) -> None:
+    async def _send_message(self, channel_id: str, msg: str, action: bool, thread_ts: str | None, re_send_to_irc: bool) -> None:
         """
         Send a message to a channel or group or whatever
 
@@ -1018,7 +1032,7 @@ class Slack:
 
         await self._send_message(channel_id, msg, action, None, re_send_to_irc)
 
-    async def event(self) -> Optional[SlackEvent]:
+    async def event(self) -> SlackEvent | None:
         """
         This returns the events from the slack websocket
         """
@@ -1050,7 +1064,7 @@ class Slack:
             debug(event)
             loadable_events = TopicChange|MessageBot|MessageEdit|MessageDelete|GroupJoined|Join|Leave|UserTyping|MpimJoined
             try:
-                ev: Optional[loadable_events] = self.tload(
+                ev: loadable_events | None = self.tload(
                     event,
                     loadable_events  # type: ignore
                 )
